==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/ResourceRequirementsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ResourceRequirementsBuilder extends ResourceRequirementsFluentImpl<ResourceRequirementsBuilder> implements VisitableBuilder<ResourceRequirements,ResourceRequirementsBuilder>{
  public ResourceRequirementsBuilder() {
    this(false);
  }
  public ResourceRequirementsBuilder(Boolean validationEnabled) {
    this(new ResourceRequirements(), validationEnabled);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ResourceRequirements(), validationEnabled);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent,ResourceRequirements instance) {
    this(fluent, instance, false);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent,ResourceRequirements instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withClaims(instance.getClaims());
      fluent.withLimits(instance.getLimits());
      fluent.withRequests(instance.getRequests());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ResourceRequirementsBuilder(ResourceRequirements instance) {
    this(instance,false);
  }
  public ResourceRequirementsBuilder(ResourceRequirements instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withClaims(instance.getClaims());
      this.withLimits(instance.getLimits());
      this.withRequests(instance.getRequests());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ResourceRequirementsFluent<?> fluent;
  Boolean validationEnabled;
  public ResourceRequirements build() {
    ResourceRequirements buildable = new ResourceRequirements(fluent.getClaims(),fluent.getLimits(),fluent.getRequests());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/ResourceRequirementsBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ResourceRequirementsBuilder extends ResourceRequirementsFluent<ResourceRequirementsBuilder> implements VisitableBuilder<ResourceRequirements,ResourceRequirementsBuilder>{
  public ResourceRequirementsBuilder() {
    this(false);
  }
  public ResourceRequirementsBuilder(Boolean validationEnabled) {
    this(new ResourceRequirements(), validationEnabled);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent) {
    this(fluent, false);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ResourceRequirements(), validationEnabled);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent,ResourceRequirements instance) {
    this(fluent, instance, false);
  }
  public ResourceRequirementsBuilder(ResourceRequirementsFluent<?> fluent,ResourceRequirements instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ResourceRequirements());

    if (instance != null) {
      fluent.withClaims(instance.getClaims());
      fluent.withLimits(instance.getLimits());
      fluent.withRequests(instance.getRequests());
      fluent.withClaims(instance.getClaims());
      fluent.withLimits(instance.getLimits());
      fluent.withRequests(instance.getRequests());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ResourceRequirementsBuilder(ResourceRequirements instance) {
    this(instance,false);
  }
  public ResourceRequirementsBuilder(ResourceRequirements instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ResourceRequirements());

    if (instance != null) {
      this.withClaims(instance.getClaims());
      this.withLimits(instance.getLimits());
      this.withRequests(instance.getRequests());
      this.withClaims(instance.getClaims());
      this.withLimits(instance.getLimits());
      this.withRequests(instance.getRequests());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ResourceRequirementsFluent<?> fluent;
  Boolean validationEnabled;
  public ResourceRequirements build() {
    ResourceRequirements buildable = new ResourceRequirements(fluent.buildClaims(),fluent.getLimits(),fluent.getRequests());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
